powered by
This is a simple helper function downloading the assets stored at https://github.com/mikemahoney218/unity_assets .
get_asset(asset, directory = NULL)
The asset to download. Available asset names are provided in available_assets.
Optionally, the directory to extract the downloaded models in. If NULL, the default, saves to tools::R_user_dir("unifir").
tools::R_user_dir("unifir")
Other utilities: add_default_player(), add_prop(), create_unity_project(), find_unity(), load_png(), load_scene(), new_scene(), read_raw(), save_scene(), set_active_scene(), validate_path(), waiver()
add_default_player()
add_prop()
create_unity_project()
find_unity()
load_png()
load_scene()
new_scene()
read_raw()
save_scene()
set_active_scene()
validate_path()
waiver()
if (interactive()) { get_asset(asset = "tree_1", directory = tempdir()) }
Run the code above in your browser using DataLab